@@ -1,16 +1,19 @@
 package Business::OnlinePayment::Ogone;
-our $AUTHORITY = 'cpan:ESSELENS';
+BEGIN {
+  $Business::OnlinePayment::Ogone::AUTHORITY = 'cpan:ESSELENS';
+}
 use parent 'Business::OnlinePayment::HTTPS';
 use strict; # keep Perl::Critic happy over common::sense;
 use common::sense;
 use Carp;
+use Data::Dumper;
 use XML::Simple qw/:strict/;
 use Digest::SHA qw/sha1_hex sha256_hex sha512_hex/;
 use MIME::Base64;
 
 # ABSTRACT: Online payment processing via Ogone
-our $VERSION = 0.2;
-our $API_VERSION = 4.9;
+our $VERSION = 0.01;
+our $API_VERSION = 3.5;
 
 # Ogone config defaults and info ######################################################################################
 
@@ -117,35 +120,27 @@ sub submit {
         http_accept => 'HTTP_ACCEPT',
         http_user_agent => 'HTTP_USER_AGENT',
 
-        # recurrent fields
-        subscription_id => 'SUBSCRIPTION_ID',
-        subscription_orderid => 'SUB_ORDERID',
-        subscription_status => 'SUBSCRIPTION_STATUS',
-        startdate => 'SUB_STARTDATE',
-        enddate => 'SUB_ENDDATE',
-        status => 'SUB_STATUS',
-        period_unit => 'SUB_PERIOD_UNIT', # 'd', 'ww', 'm' (yes two 'w's) for resp daily weekly monthly
-        period_moment => 'SUB_PERIOD_MOMENT', # Integer, the moment in time on which the payment is (0-7 when period_unit is ww, 1-31 for d, 1-12 for m?)
-        period_number => 'SUB_PERIOD_NUMBER', 
+
     );
 
     # Only allow max of 2 digits after comma as we need to int ( $amount * 100 ) for Ogone
     croak 'max 2 digits after comma (or dot) allowed' if $self->{_content}->{amount} =~ m/[\,\.]\d{3}/;
 
     # Ogone has multiple users per login, defaults to login
-    $self->{_content}->{PSPID}      ||= $self->{pspid} || $self->{PSPID} || $self->{login} || $self->{_content}->{login};
+    $self->{_content}->{PSPID}      ||= $self->{PSPID} || $self->{login} || $self->{_content}->{login};
 
     # Login information, default to constructor values
     $self->{_content}->{login}      ||= $self->{login};
     $self->{_content}->{password}   ||= $self->{password};
+    $self->{_content}->{PSPID}      ||= $self->{PSPID};
 
     # Default Operation request for authorization (RES) for authorization only, (capture full and close) SAS for post authorization
     $self->{_content}->{operation}  ||= 'RES' if $self->{_content}->{action} =~ m/authorization only/;
     $self->{_content}->{operation}  ||= 'SAL' if $self->{_content}->{action} =~ m/normal authorization/;
     $self->{_content}->{operation}  ||= 'SAS' if $self->{_content}->{action} =~ m/post authorization/;
 
-    # Default ECI is SSL e-commerce (7) or Recurring with e-commerce (9) if subscription_id exists
-    $self->{_content}->{eci}        ||= $self->{_content}->{subscription_id} ? 9 : 7;
+    # Default ECI is SSL e-commerce (7)
+    $self->{_content}->{eci}        ||= 7;
 
     # Remap the fields to their Ogone-API counterparts ie: cvc => CVC
     $self->remap_fields(%ogone_api_args);
@@ -156,7 +151,6 @@ sub submit {
     my @args_basic  = (qw/login password PSPID action/);
     my @args_ccard  = (qw/card_number expiration cvc/);
     my @args_alias  = (qw/alias cvc/);
-    my @args_recur  = (@args_basic, qw/name subscription_id subscription_orderid invoice_number amount currency startdate enddate period_unit period_moment period_number/, $self->{_content}->{card_numer} ? @args_ccard : @args_alias ), 
     my @args_new    = (@args_basic, qw/invoice_number amount currency/, $self->{_content}->{card_number} ? @args_ccard : @args_alias);
     my @args_post   = (@args_basic, qw/invoice_number/);
     my @query       = (@args_basic, qw/invoice_number/);
@@ -166,8 +160,7 @@ sub submit {
         qr/normal authorization/i    => \@args_new,
         qr/authorization only/i      => \@args_new,
         qr/post authorization/i      => \@args_post,
-        qr/query/i                   => \@query,
-        qr/recurrent authorization/i => \@args_recur
+        qr/query/i                   => \@query
     );
 
     # Compile a list of required arguments
@@ -175,7 +168,7 @@ sub submit {
                 grep { $self->{_content}->{action} =~ $_ }      # compare action input against regex key
                 keys %action_arguments;                         # extract regular expressions
 
-    croak 'unable to determine HTTP POST @args, is the action parameter one of ( authorization only | normal authorization | post authorization | query | recurrent authorization )' unless @args;
+    croak 'unable to determine HTTP POST @args, is the action parameter one of ( authorization only | normal authorization | post authorization | query )' unless @args;
 
     # Enforce the field requirements by calling parent
     my @undefs = grep { ! defined $self->{_content}->{$_} } @args;
@@ -197,19 +190,8 @@ sub submit {
                         map { $ogone_api_args{$_} || $_ } @all_http_args;
 
     # Ogone accepts the amount as 100 fold in integer form.
-    # # Adding 0.5 to amount to prevent "rounding" errors, see http://stackoverflow.com/a/1274692 or perldoc -q round
-    $http_req_args{amount} = int(100 * $http_req_args{amount} + 0.5) if exists $http_req_args{amount};
-
-    # Map normal fields to their SUB_ counterparts when recurrent authorization is used
-    if($self->{_content}->{action} =~ m/recurrent authorization/) {
-        $http_req_args{SUB_COMMENT} = $http_req_args{COM} if exists $http_req_args{COM};
-        $http_req_args{SUB_AMOUNT} = $http_req_args{amount};
-        $http_req_args{SUB_ORDERID} = $http_req_args{orderID};
-    }
-
-    # PSPID might be entered in lowercase (as per old documentation)
-    $http_req_args{PSPID} = $self->{_content}{pspid} if defined $self->{_content}{pspid};
-
+    $http_req_args{amount} = int(100 * $http_req_args{amount}) if exists $http_req_args{amount};
+   
     # Calculate sha1 by default, but has to be enabled in the Ogone backend to have any effect
     my ($sha_type)  = ($self->{_content}->{sha_type} =~ m/^(1|256|512)$/);
 
@@ -217,7 +199,7 @@ sub submit {
     my $sha_hex = sub { my $type = shift; no strict; &{"sha".($type || 1)."_hex"}(@_); use strict; };
 
     # Algo: make a list of "KEY=value$passphrase" sort alphabetically
-    my $signature = join('',
+    my $signature =  join('',
                          sort map { uc($_) . "=" . $http_req_args{$_} . ($self->{_content}{sha_key} || '') }
                          keys %http_req_args);
 
@@ -227,7 +209,6 @@ sub submit {
     my %action_file = (
         qr/normal authorization/i  => 'orderdirect.asp',
         qr/authorization only/i    => 'orderdirect.asp',
-        qr/recurrent authorization/i    => 'orderdirect.asp',
         qr/post authorization/i    => 'maintenancedirect.asp',
         qr/query/i                 => 'querydirect.asp',
     );
@@ -237,7 +218,7 @@ sub submit {
                       grep { $self->{_content}->{action} =~ $_ }
                       keys %action_file;
 
-    croak 'unable to determine URI path, is the action parameter one of ( authorization only | normal authorization | post authorization | query | recueent authorization)' unless $uri_file;
+    croak 'unable to determine URI path, is the action parameter one of ( authorization only | normal authorization | post authorization | query )' unless $uri_file;
     
     # Construct the path to be used in https_post
     $self->{path} = '/ncol/'.$uri_dir.'/'.$uri_file;
@@ -269,7 +250,6 @@ sub submit {
         if ( $xml->{STATUS} == 5  ) { $self->is_success(1) } # authorization accepted
         if ( $xml->{STATUS} == 9  ) { $self->is_success(1) } # payment accepted
         if ( $xml->{STATUS} == 91 ) { $self->is_success(1) } # partial payment accepted
-        if ( $xml->{STATUS} == 61 ) { $self->is_success(1) } # Author. deletion waiting
         if ( $xml->{STATUS} == 2 ) { $self->failure_status('refused') } # authorization refused
         if ( $xml->{STATUS} == 0 && $xml->{NCERROR} eq '50001134' ) { $self->failure_status('declined') } # 3d secure wrong identification
         if ( $xml->{STATUS} == 0 && $xml->{NCERRORPLUS} =~ m/status \(91\)/ ) { 
@@ -382,8 +362,6 @@ Laser, Privilège, Solo, MaestroUK, UATP
 
 =item * allows creation of VISA Alias mitigating the need to store them temporary (RES -> SAL)
 
-=item * allows creation of Recurrent VISA bills (Subscriptions)
-
 =item * close coupling to native API, easy to crossreference
 
 =item * allows Ogone's native operations: RES, REN, DEL, DES, SAL, SAS, RFD, RFS
@@ -480,17 +458,6 @@ C<action>, C<alias>, C<win3ds>.
         http_accept => 'HTTP_ACCEPT',
         http_user_agent => 'HTTP_USER_AGENT',
 
-        # recurrent fields
-        subscription_id => 'SUBSCRIPTION_ID',
-        subscription_orderid => 'SUB_ORDERID',
-        subscription_status => 'SUBSCRIPTION_STATUS',
-        startdate => 'SUB_STARTDATE',
-        enddate => 'SUB_ENDDATE',
-        status => 'SUB_STATUS',
-        period_unit => 'SUB_PERIOD_UNIT', # 'd', 'ww', 'm' (yes two 'w's) for resp daily weekly monthly
-        period_moment => 'SUB_PERIOD_MOMENT', # Integer, the moment in time on which the payment is (0-7 when period_unit is ww, 1-31 for d, 1-12 for m?)
-        period_number => 'SUB_PERIOD_NUMBER', 
-
 =head3 content() required parameters
 
 Depending on what action you are triggering a number of parameters are required. You can use the following pseudo perl
@@ -499,7 +466,6 @@ code as a reference to what exactly is required depending on the parameters.
     my @args_basic  = qw/login password PSPID action/;
     my @args_ccard  = qw/card_number expiration cvc/;
     my @args_alias  = qw/alias cvc/;
-    my @args_recur  = (@args_basic, qw/name subscription_id subscription_orderid invoice_number amount currency startdate enddate period_unit period_moment period_number/, has_cc_number() ? @args_ccard : @args_alias ), 
     my @args_new    = @args_basic, qw/invoice_number amount currency/, has_cc_number() ? @args_ccard : @args_alias;
     my @args_post   = @args_basic, qw/invoice_number/;
     my @query       = @args_basic, qw/invoice_number/;
@@ -513,14 +479,14 @@ code as a reference to what exactly is required depending on the parameters.
 
 =head2 content() examples
 
-=head3 example B<authorization only> request: requests a claim on an amount of money [RES] (and creates an alias)
+=head3 example B<authorize only> request: requests a claim on an amount of money [RES] (and creates an alias)
 
     my %auth = ( pspid => 'fred', login => 'bedrock_api', password => 'fl1nst0ne' );
 
     my $id = $session->get('orderid');
     my $res = new Business::OnlinePayment('Ogone', %auth);
 
-    $res->content( invoice_number => $id, action => 'authorization only', alias => 'wilma flinstone',  ... );
+    $res->content( invoice_number => $id, action => 'authorize only', alias => 'wilma flinstone',  ... );
     $res->submit();
 
     if ( $res->is_success() ) {
@@ -542,37 +508,13 @@ code as a reference to what exactly is required depending on the parameters.
 
     my $res = new Business::OnlinePayment('Ogone',%auth);
 
-    $res->content(alias => 'wilma_flinstone', cvc => 123, ...);
+    $res->content(alias => 'wilma flinstone', cvc => 123, ...);
     $res->submit();
 
     if ( $res->is_success() ) {
         $dbh->do('insert into tx_status_log (id,status) values (?,?)',undef,$id,"RES OK");
     };
 
-=head3 example with B<recurrent> transaction using an alias
-
-    my $res = new Business::OnlinePayment('Ogone',%auth);
-    
-    $res->content(  action => 'recurrent authorization',
-                    alias => 'wilma_finstone',
-                    name => 'Wilma Flinstone', 
-                    cvc => '423',
-                    amount => '42',
-                    description => "monthly subscription to bedrock magazine",
-                    subscription_id => 12312312
-                    invoice_number => 9123,
-                    subscription_orderid => 123112,
-                    startdate => '2012-01-01',
-                    enddate => '2013-01-01',
-                    status => 1,
-                    period_unit => 'm',
-                    period_moment => 1,
-                    period_number => 1,
-                    ... );
-
-    $res->submit();
-);
-
 
 =head3 Optional parameters 
 
@@ -591,33 +533,33 @@ code as a reference to what exactly is required depending on the parameters.
 
 =head1 STATE DIAGRAMS
 
-=head2 Authorization Only
+=head2 Authorize Only
 
          Client                                 Ogone HTTPS      Bank
       ------------------------------------------------------------------------
 
-      1    +---|Authorization Only| orderID=1----------->. [RES]
-                                                         |
-      2    *<---STATUS=5 ---------0000-------------------'
+      1    +---|Authorize Only| orderID=1----------->. [RES]        
+                                                     |              
+      2    *<---STATUS=5 ----------------------------'                    
 
 =over 4
 
-=item B<1> submit authorization only request usin RES operation with orderID=1. This will reserve the money on the credit card.
+=item B<1> submit authorize only request usin RES operation with orderID=1. This will reserve the money on the credit card.
 
 =item B<2> STATUS=5 indicates the authorization succeeded.
 
 =back
   
-=head2 Post Authorization
+=head2 Post Authorize
 
          Client                                 Ogone HTTPS      Bank
       ------------------------------------------------------------------------
 
-      1    +---|Post Authorization| orderID=1----------->. [SAL] 
-                                                         |
-      2    *<---STATUS=91 PAYID=.. PAYIDSUB=.. ----------+ (processing)
-                                                         |
-      3                                                  `------->.
+      1    +---|Post Authorize| orderID=1----------->. [SAL] 
+                                                     |
+      2    *<---STATUS=91 PAYID=.. PAYIDSUB=.. ------+ (processing)
+                                                     |
+      3                                              `----------->.
                                                                   | (processed) +$
       4                                     STATUS=9 .<-----------'
 
@@ -678,6 +620,8 @@ code as a reference to what exactly is required depending on the parameters.
 
 =item * use SHA1 passwd hashing see: L<https://secure.ogone.com/ncol/test/hash_pswd.aspi>
 
+=item * test and implement visa aliases
+
 =back
 
 =head1 TESTING
@@ -685,9 +629,9 @@ code as a reference to what exactly is required depending on the parameters.
 To test this module you will need to set your credentials in the environment. Put the following in a file in your hoe directory e.g. F<~/.ogone>
 The password is not the same as the PSPID password, you will need to enter the API users' password.
 
-    export OGONE_PSPID=bob
-    export OGONE_USERID=bob_api
-    export OGONE_PSWD=foobar
+    OGONE_PSPID=bob
+    OGONE_USERID=bob_api
+    OGONE_PSWD=foobar
     
 Limit access to the F<~/.ogone> file
 
