@@ -1,5 +1,7 @@
 package Ogone::Status;
-our $AUTHORITY = 'cpan:ESSELENS';
+BEGIN {
+  $Ogone::Status::AUTHORITY = 'cpan:ESSELENS';
+}
 
 # ABSTRACT: Ogone status maps
 # from https://secure.ogone.com/ncol/paymentinfos1.asp on 2010-11-17
